==> tencentcloud-sdk-java-3.1.62-sources.jar: com/tencentcloudapi/faceid/v20180301/models/GetActionSequenceRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.faceid.v20180301.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class GetActionSequenceRequest extends AbstractModel{

    /**
    * 取值FourAction时 返回四种动作的动作序列
    */
    @SerializedName("ActionType")
    @Expose
    private String ActionType;

    /**
     * Get 取值FourAction时 返回四种动作的动作序列 
     * @return ActionType 取值FourAction时 返回四种动作的动作序列
     */
    public String getActionType() {
        return this.ActionType;
    }

    /**
     * Set 取值FourAction时 返回四种动作的动作序列
     * @param ActionType 取值FourAction时 返回四种动作的动作序列
     */
    public void setActionType(String ActionType) {
        this.ActionType = ActionType;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "ActionType", this.ActionType);

    }
}

==> tencentcloud-sdk-java-3.1.79-sources.jar: com/tencentcloudapi/faceid/v20180301/models/GetActionSequenceRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.faceid.v20180301.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class GetActionSequenceRequest extends AbstractModel{

    /**
    * 默认不需要使用
    */
    @SerializedName("ActionType")
    @Expose
    private String ActionType;

    /**
     * Get 默认不需要使用 
     * @return ActionType 默认不需要使用
     */
    public String getActionType() {
        return this.ActionType;
    }

    /**
     * Set 默认不需要使用
     * @param ActionType 默认不需要使用
     */
    public void setActionType(String ActionType) {
        this.ActionType = ActionType;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "ActionType", this.ActionType);

    }
}
